@@ -1,4 +1,4 @@
-# Copyright (C) 2010-2011 Torsten Schoenfeld <kaffeetisch@gmx.de>
+# Copyright (C) 2010-2012 Torsten Schoenfeld <kaffeetisch@gmx.de>
 #
 # This library is free software; you can redistribute it and/or modify it under
 # the terms of the GNU Library General Public License as published by the Free
@@ -20,7 +20,7 @@ use strict;
 use warnings;
 use Glib;
 
-our $VERSION = 0.005;
+our $VERSION = 0.006;
 
 use Carp;
 $Carp::Internal{(__PACKAGE__)}++;
@@ -174,8 +174,7 @@ sub setup {
             next VFUNC;
           }
           *{$full_perl_vfunc_name} = sub {
-            __PACKAGE__->_invoke_fallback_vfunc($basename,
-                                                $parent_package,
+            __PACKAGE__->_invoke_fallback_vfunc($parent_package,
                                                 $vfunc_name,
                                                 $first_parent,
                                                 @_);
